aboutsummaryrefslogtreecommitdiff
path: root/src/lib/bootmode.c
diff options
context:
space:
mode:
authorJoel Kitching <kitching@google.com>2019-04-10 16:06:21 +0800
committerJulius Werner <jwerner@chromium.org>2019-04-30 21:47:25 +0000
commit6672bd8e6b808300a98be0ce308a2bfe5b4685d6 (patch)
tree9bd6699009566d63dc7bf4417b7ab6e23436f3d2 /src/lib/bootmode.c
parent2b8789bb3bf186b64ead7a92c341eb70ed57bbcf (diff)
vboot: refactor OPROM code
The name OPROM is somewhat inaccurate, since other steps to bring up display and graphics are needed depending on mainboard/SoC. This patch cleans up OPROM code nomenclature, and works towards the goal of deprecating vboot1: * Rename CONFIG_VBOOT_OPROM_MATTERS to CONFIG_VBOOT_MUST_REQUEST_DISPLAY and clarify Kconfig description * Remove function vboot_handoff_skip_display_init * Remove use of the VbInit oflag VB_INIT_OUT_ENABLE_DISPLAY * Add |flags| field to vboot_working_data struct * Create VBOOT_FLAG_DISPLAY_REQUESTED and set in vboot_handoff BUG=b:124141368, b:124192753, chromium:948529 TEST=make clean && make test-abuild TEST=build and flash eve device; attempt loading dev/rec modes BRANCH=none Change-Id: Idf111a533c3953448b4b9084885a9a65a2432a8b Signed-off-by: Joel Kitching <kitching@google.com> Reviewed-on: https://review.coreboot.org/c/coreboot/+/32262 Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: Julius Werner <jwerner@chromium.org>
Diffstat (limited to 'src/lib/bootmode.c')
-rw-r--r--src/lib/bootmode.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/lib/bootmode.c b/src/lib/bootmode.c
index 052eb8f282..18f6d5dcac 100644
--- a/src/lib/bootmode.c
+++ b/src/lib/bootmode.c
@@ -35,12 +35,14 @@ void gfx_set_init_done(int done)
int display_init_required(void)
{
/* For vboot always honor vboot_handoff_skip_display_init(). */
if (CONFIG(VBOOT)) {
- /* Must always select OPROM_MATTERS when using this function. */
- if (!CONFIG(VBOOT_OPROM_MATTERS))
+ /* Must always select MUST_REQUEST_DISPLAY when using this
+ function. */
+ if (!CONFIG(VBOOT_MUST_REQUEST_DISPLAY))
dead_code();
- return !vboot_handoff_skip_display_init();
+ return vboot_get_working_data()->flags
+ & VBOOT_WD_FLAG_DISPLAY_INIT;
}
/* By default always initialize display. */
@@ -35,12 +35,14 @@ void gfx_set_init_done(int done)
int display_init_required(void)
{
- /* For vboot always honor vboot_handoff_skip_display_init(). */
+ /* For vboot, always honor VBOOT_WD_FLAG_DISPLAY_INIT. */
if (CONFIG(VBOOT)) {